@@ -970,7 +970,7 @@ GogView *
 gog_graph_view_get_selection (GogGraphView *gview)
 {
 	g_return_val_if_fail (IS_GOG_GRAPH_VIEW (gview), NULL);
-	
+
 	return gview->selected_view;
 }
 
@@ -986,7 +986,7 @@ void
 gog_graph_view_set_selection (GogGraphView *gview, GogObject *gobj)
 {
 	GogView *view;
-	
+
 	g_return_if_fail (IS_GOG_GRAPH_VIEW (gview));
 	g_return_if_fail (IS_GOG_OBJECT (gobj));
 
@@ -1063,36 +1063,30 @@ gog_graph_export_image (GogGraph *graph, GOImageFormat format, GsfOutput *output
 	g_return_val_if_fail (IS_GOG_GRAPH (graph), FALSE);
 	g_return_val_if_fail (format != GO_IMAGE_FORMAT_UNKNOWN, FALSE);
 
-	renderer = gog_renderer_new_for_format (graph, format);
-	g_return_val_if_fail (renderer != NULL, FALSE);
-
+	renderer = gog_renderer_new (graph);
 	result = gog_renderer_export_image (renderer, format, output, x_dpi, y_dpi);
 	g_object_unref (renderer);
 
 	return result;
 }
 
-void gog_graph_render_to_cairo (GogGraph *graph, gpointer data, double w, double h)
-{
-	GogRenderer *rend = GOG_RENDERER (g_object_new (
-		GOG_RENDERER_TYPE,
-		"model", graph,
-		"cairo", data,
-		"is-vector", FALSE,
-		NULL));
-	gog_renderer_update (rend, w, h, 1.);
-	g_object_unref (rend);
-}
+/**
+ * gog_graph_render_to_cairo:
+ * @graph: a #GogGraph
+ * @cairo: a cairo context
+ * @w: width
+ * @h: height
+ *
+ * Renders a graph using @cairo. @w and @h are the requested width an height of the rendered graph, in the current @cairo coordinate space. This function is not suited for multiple rendering of the same graph. gog_renderer_render_to cairo or gog_renderer_update/gog_renderer_get_cairo_surface should be used instead.
+ **/
 
-void gog_graph_render_to_cairo_vector (GogGraph *graph, gpointer data, double w, double h)
+void gog_graph_render_to_cairo (GogGraph *graph, cairo_t *cairo, double w, double h)
 {
-	GogRenderer *rend = GOG_RENDERER (g_object_new (
-		GOG_RENDERER_TYPE,
-		"model", graph,
-		"cairo", data,
-		"is-vector", TRUE,
-		NULL));
-	gog_renderer_update (rend, w, h, 1.);
-	g_object_unref (rend);
-}
+	GogRenderer *renderer;
 
+	g_return_if_fail (IS_GOG_GRAPH (graph));
+
+	renderer = gog_renderer_new (graph);
+	gog_renderer_render_to_cairo (renderer, cairo, w, h);
+	g_object_unref (renderer);
+}
