@@ -93,12 +93,24 @@ void         go_mem_chunk_foreach_leak	(GOMemChunk *chunk, GFunc cb, gpointer us
 
 void	go_object_toggle             (gpointer object,
 				      const gchar *property_name);
+gboolean go_object_set_property (GObject *obj, const char *property_name,
+				 const char *user_prop_name, const char *value,
+				 GError **err,
+				 const char *error_template);
 GSList *go_object_properties_collect (GObject *obj);
 void    go_object_properties_apply   (GObject *obj,
 				      GSList *props,
 				      gboolean changed_only);
 void    go_object_properties_free    (GSList *props);
 
+gboolean go_parse_key_value (const char *options,
+			     GError **err,
+			     gboolean (*handler) (const char *name,
+						  const char *value,
+						  GError **err,
+						  gpointer user),
+			     gpointer user);
+
 G_END_DECLS
 
 #endif /* GO_GLIB_EXTRAS_H */
